@@ -214,14 +214,12 @@ class ParametersModel(dv.PyDataViewModel):
                     par.range(low, high)
 
         if col == 0:
-            # if the number of fitting parameters changes then this is
-            # considered a model update rather than a simple parameter
-            # update; parameter values didn't change, so dirty=False, and
-            # model.model_update() will not be called and the theory value
-            # will not be re-computed.
-            signal.update_model(model=self.model, dirty=False)
-        else:
-            signal.update_parameters(model=self.model, delay=1)
+            # if the number of fitting parameters changes then we have to
+            # call model_reset in order to recalculate the varying parameters
+            # (needed for dof calculations and SummaryView)
+            self.model.model_reset()
+
+        signal.update_parameters(model=self.model, delay=1)
         return True
 
 class ParameterView(wx.Panel):
